package com.muyu.system.controller;

import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.controller.BaseController;
import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.log.annotation.Log;
import com.muyu.common.log.enums.BusinessType;
import com.muyu.common.security.annotation.RequiresPermissions;
import com.muyu.common.security.utils.SecurityUtils;
import com.muyu.system.domain.SysNotice;
import com.muyu.system.domain.resp.NoticeAndCountResp;
import com.muyu.system.service.SysNoticeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.HashSet;
import java.util.List;

/**
 * 公告 信息操作处理
 *
 * @author muyu
 */
@RestController
@RequestMapping("/notice")
public class SysNoticeController extends BaseController {
    @Autowired
    private SysNoticeService noticeService;

    /**
     * 获取通知公告列表
     */
    @RequiresPermissions("system:notice:list")
    @GetMapping("/list")
    public Result<TableDataInfo<SysNotice>>  list (SysNotice notice) {
        startPage();
        List<SysNotice> list = noticeService.selectNoticeList(notice);
        return getDataTable(list);
    }

    @RequiresPermissions("system:notice:userList")
    @PostMapping("/userList")
    public Result userList (SysNotice notice) {
        startPage();
        Long userId = SecurityUtils.getUserId();
        List<SysNotice> list = noticeService.selectNoticeUserList(notice,userId);
        return Result.success(list);
    }
    /**
     * 根据通知公告编号获取详细信息
     */
    @RequiresPermissions("system:notice:query")
    @GetMapping(value = "/{noticeId}")
    public Result getInfo (@PathVariable("noticeId") Long noticeId) {
        return success(noticeService.selectNoticeById(noticeId));
    }
    /**
     * 根据通知公告编号获取详细信息和阅读量
     */

    @RequiresPermissions("system:notice:query")
    @PostMapping(value = "/{noticeId}")
    public Result noticeAndCount (@PathVariable("noticeId") Long noticeId) {

        NoticeAndCountResp noticeCount = noticeService.getNoticeCount(noticeId);
        return success(noticeCount);
    }
    public static final String TongZhi_ONE = "1";
    public static final String GongGao_TWO = "2";
    /**
     * 阅读消息操作
     */
    @Transactional
    @RequiresPermissions("system:notice:query")
    @PutMapping(value = "/{noticeId}")
    public Result readNotice (@PathVariable("noticeId") Long noticeId) {

        SysNotice notice = noticeService.selectNoticeById(noticeId);
        Date startTime = notice.getStartTime();
        Date endTime = notice.getEndTime();
        if (GongGao_TWO.equals(notice.getNoticeType())){
            Date date = new Date();
            int ss= startTime.compareTo(date);
            int ee = endTime.compareTo(date);
            if (ss>0){
return Result.error("公告时间未到");
            }else if (ee<0){
                return Result.error("公告时间已过");
            }
        }
        SysNotice sysNotice = noticeService.selectNoticeById(noticeId);
        Long userId = SecurityUtils.getUserId();
         noticeService.updateReadStatusByUserIdAndNoticeId(noticeId,userId);
        return success(sysNotice);
    }


    /**
     * 新增通知公告
     */
    @RequiresPermissions("system:notice:add")
    @Log(title = "通知公告", businessType = BusinessType.INSERT)
    @PostMapping
    public Result add (@Validated @RequestBody SysNotice notice) {
        notice.setCreateBy(SecurityUtils.getUsername());
        System.out.println(SecurityUtils.getUsername());
        List<Integer> userIds = notice.getUserIds();

        HashSet<Integer> userHashSet = new HashSet<>();
        if (TongZhi_ONE.equals(notice.getNoticeType())){
//消息类型为通告时(1)
            userHashSet.addAll(userIds);
            if (StringUtils.isNotNull(notice.getDeptIds())){

                //将部门DeptIds下对应的部门成员添加到userHashSet
                List<List<Integer>> deptIdsList = notice.getDeptIds();
        //创建部门id集合
                ArrayList<Integer> deptIdsarrayList = new ArrayList<>();

                for (List<Integer> integers : deptIdsList) {
                    //将传入部门ids第三层部门添加到部门id集合
                    deptIdsarrayList.add(integers.get(2));
                }
                //通过部门id集合查询对应的用户ids集合
             List<Integer>  userIdsByDeptIds =   noticeService.selectUserIdsByDeptIds(deptIdsarrayList);
                userHashSet.addAll(userIdsByDeptIds);
            }

        }else {
            //消息类型为公告时(2) 向所有人发公告
            //查询所有人的userId
            List<Integer> addUserIds = noticeService.selectAddUserIds();
            userHashSet.addAll(addUserIds);
        }
        return toAjax(noticeService.insertNotice(notice,userHashSet));
    }

    /**
     * 修改通知公告
     */
    @RequiresPermissions("system:notice:edit")
    @Log(title = "通知公告", businessType = BusinessType.UPDATE)
    @PutMapping
    public Result edit (@Validated @RequestBody SysNotice notice) {
        notice.setUpdateBy(SecurityUtils.getUsername());
        return toAjax(noticeService.updateNotice(notice));
    }





    /**
     * 删除通知公告
     */
    @RequiresPermissions("system:notice:remove")
    @Log(title = "通知公告", businessType = BusinessType.DELETE)
    @DeleteMapping("/{noticeIds}")
    public Result remove (@PathVariable("noticeIds") Long[] noticeIds) {
        return toAjax(noticeService.deleteNoticeByIds(noticeIds));
    }
}
