package com.muyu.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.muyu.system.domain.SysNotice;
import com.muyu.system.domain.resp.NoticeAndCountResp;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;

/**
 * 公告 服务层
 *
 * @author muyu
 */
public interface SysNoticeService extends IService<SysNotice> {
    /**
     * 查询公告信息
     *
     * @param noticeId 公告ID
     *
     * @return 公告信息
     */
    public SysNotice selectNoticeById (Long noticeId);




    /**
     * 查询公告列表
     *
     * @param notice 公告信息
     *
     * @return 公告集合
     */
    public List<SysNotice> selectNoticeList (SysNotice notice);

    /**
     * 新增公告
     *
     * @param notice      公告信息
     * @param userHashSet
     * @return 结果
     */
    public int insertNotice (SysNotice notice, HashSet<Integer> userHashSet);

    /**
     * 修改公告
     *
     * @param notice 公告信息
     *
     * @return 结果
     */
    public int updateNotice (SysNotice notice);

    /**
     * 删除公告信息
     *
     * @param noticeId 公告ID
     *
     * @return 结果
     */
    public int deleteNoticeById (Long noticeId);

    /**
     * 批量删除公告信息
     *
     * @param noticeIds 需要删除的公告ID
     *
     * @return 结果
     */
    public int deleteNoticeByIds (Long[] noticeIds);

    /**
     * 查询用户的公告信息
     * @param notice
     * @param userId
     * @return
     */
    List<SysNotice> selectNoticeUserList(SysNotice notice, Long userId);
    /**
     * 查询消息的详细信息和阅读量
     * @param noticeId
     * @return
     */

  public   NoticeAndCountResp getNoticeCount(Long noticeId);

    /**
     * 修改消息的阅读状态
     * @param noticeId
     * @param userId
     */
   public int updateReadStatusByUserIdAndNoticeId(Long noticeId, Long userId);

    List<Integer> selectUserIdsByDeptIds(ArrayList<Integer> deptIdsarrayList);

    List<Integer> selectAddUserIds();

}
