package com.muyu.system.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.system.domain.SysNotice;
import com.muyu.system.domain.resp.NoticeAndCountResp;
import com.muyu.system.mapper.SysNoticeMapper;
import com.muyu.system.service.SysNoticeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;

/**
 * 公告 服务层实现
 *
 * @author muyu
 */
@Service
public class SysNoticeServiceImpl extends ServiceImpl<SysNoticeMapper, SysNotice> implements SysNoticeService {
    @Autowired
    private SysNoticeMapper noticeMapper;

    /**
     * 查询公告信息
     *
     * @param noticeId 公告ID
     *
     * @return 公告信息
     */
    @Override
    public SysNotice selectNoticeById (Long noticeId) {
        return noticeMapper.selectNoticeById(noticeId);
    }



    /**
     *  用户消息列表
     * @param notice
     * @param userId
     * @return
     */

    @Override
    public List<SysNotice> selectNoticeUserList(SysNotice notice, Long userId) {
        return noticeMapper.selectNoticeUserList(notice,userId);
    }


    /**
     * 查询公告列表
     *
     * @param noticeId 公告信息
     *
     * @return 公告集合
     */
    @Override
    public NoticeAndCountResp getNoticeCount(Long noticeId) {


        return noticeMapper.getNoticeCount(noticeId);
    }

    @Override
    public int updateReadStatusByUserIdAndNoticeId(Long noticeId, Long userId) {

        return noticeMapper.updateReadStatusByUserIdAndNoticeId(noticeId,userId);
    }

    @Override
    public List<Integer> selectUserIdsByDeptIds(ArrayList<Integer> deptIdsarrayList) {

        return noticeMapper.selectUserIdsByDeptIds(deptIdsarrayList);
    }

    @Override
    public List<Integer> selectAddUserIds() {
        return noticeMapper.selectAddUserIds();
    }

    /**
     * 查询公告列表
     *
     * @param notice 公告信息
     *
     * @return 公告集合
     */
    @Override
    public List<SysNotice> selectNoticeList (SysNotice notice) {
        return noticeMapper.selectNoticeList(notice);
    }

    /**
     * 新增公告
     *
     * @param notice      公告信息
     * @param userHashSet
     * @return 结果
     */
    @Transactional
    @Override
    public int insertNotice (SysNotice notice, HashSet<Integer> userHashSet) {

        int i = noticeMapper.insertNotice(notice);

        if (i>0 && StringUtils.isNotNull(userHashSet)){
            //传入消息id和存储用户id的set集合添加中间表
            noticeMapper.addMiddle(notice.getNoticeId(),userHashSet);
        }

        return i;
    }

    /**
     * 修改公告
     *
     * @param notice 公告信息
     *
     * @return 结果
     */
    @Override
    public int updateNotice (SysNotice notice) {
        return noticeMapper.updateNotice(notice);
    }

    /**
     * 删除公告对象
     *
     * @param noticeId 公告ID
     *
     * @return 结果
     */
    @Override
    public int deleteNoticeById (Long noticeId) {
        return noticeMapper.deleteNoticeById(noticeId);
    }

    /**
     * 批量删除公告信息
     *
     * @param noticeIds 需要删除的公告ID
     *
     * @return 结果
     */
    @Override
    public int deleteNoticeByIds (Long[] noticeIds) {
        return noticeMapper.deleteNoticeByIds(noticeIds);
    }


}
